@@ -252,6 +252,10 @@ class ezfuc(object):
         """
         检查两个列表内容是否一致，与位置无关
         """
+        old_data = list(set(old_data))
+        new_data = list(set(new_data))
+        if len(old_data) != len(new_data):
+            return False
         if isinstance(ezfuc.get_first(old_data), dict):
             old_data_md5 = [ezfuc.md5(i.values()) for i in old_data]
             new_data_md5 = [ezfuc.md5(i.values()) for i in new_data]
@@ -264,6 +268,15 @@ class ezfuc(object):
         else:
             return False
 
+    @staticmethod
+    def get_time():
+    	"""
+    	获取当前时间
+    	"""
+    	import time
+	    now_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
+	    return str(now_time)
+
     @staticmethod
     def random_ua():
         """
@@ -502,7 +515,7 @@ class EmailSend(object):
 @ezfuc.retry(2)
 def getIP():
     try:
-        res = requests.get("http://192.168.18.8:39111/123",timeout=3).json()
+        res = requests.get("http://192.168.18.47:39111/123",timeout=3).json()
     except:
         return None
 
